# 1. Introduction

- implement software tool for experiments with restarting automata
- should be able to straightforward design, simulate, store and test given automata
- should have constrains for different types of restarting automata which will not allow some instructions
- the emphasis is put on easy to use and extendability of new types of restarting automata
- check determinism, ... of given automata
- check if automata is monotonic
- presenting automata on web with simulation / which allow users to test automata with theirs own words

# 2. Related work

- libraries for work with automata "fado", grail
- what was done (up)
- related work with automata
- usage on reduction analysis of natural languages
- what is automaton
- rrww .... definitions, constrains, monotonic

# 3. Analysis

- why i choose Python from all languages
- why i choose json
- why i choose this text format
- why I used django and not flask
- how i get here / what I tried and fail and what succeed
- what libraries and algorithms was chosen and why alternatives and pros and cons

=> nic takoveho neexistuje... jiny model a pro tento model nic nebylo
peter Cerno

# 4. Specifications

- similar to introduction but detailed

# 5. Development / Design

- how it all works together

## Technology

- django
- python3
- json

## Data format

- text
- json

## Structure

- what is in library
- specific methods from library and theirs
- how is the project structured / web and library + library methods

## methods

- what is monotonous automaton /left right
- constrains -> RRWW RRW ...
- speed of algorithm
- correctness of methods

# 6. Experiments / tests

- how long it takes
- some automata
- hardware test - specification

# 7. User documentation

- how to install
- how to use
- tutorials / scenarios

# 8. Programmer documentation

- format of protocols that communicate with server/web client
- how to expand types
- how to expand tests

# 9. conclusion

# literature

link [restarting automata - bc ](https://is.cuni.cz/webapps/zzp/detail/49108/52450341/?q=%7B"______searchform___search"%3A"%5Cu010derno"https://is.cuni.cz/webapps/zzp/detail/49108/52450341/?q=%7B"______searchform___search"%3A"%5Cu010derno"%2C"______searchform___butsearch"%3A"Vyhledat"%2C"______facetform___facets___workType"%3A%5B"BP"%5D%2C"PNzzpSearchListbasic"%3A1%7D&lang=csC"______searchform___butsearch"%3A"Vyhledat"https://is.cuni.cz/webapps/zzp/detail/49108/52450341/?q=%7B"______searchform___search"%3A"%5Cu010derno"%2C"______searchform___butsearch"%3A"Vyhledat"%2C"______facetform___facets___workType"%3A%5B"BP"%5D%2C"PNzzpSearchListbasic"%3A1%7D&lang=csC"______facetform___facets___workType"%3A%5B"BP"%5Dhttps://is.cuni.cz/webapps/zzp/detail/49108/52450341/?q=%7B"______searchform___search"%3A"%5Cu010derno"%2C"______searchform___butsearch"%3A"Vyhledat"%2C"______facetform___facets___workType"%3A%5B"BP"%5D%2C"PNzzpSearchListbasic"%3A1%7D&lang=csC"PNzzpSearchListbasic"%3A1%7D&lang=cs)
